@@ -40,10 +40,10 @@ impl<'a> UpdateChannelPermissionConfigured<'a> {
     ) -> Self {
         let (name, target_id) = match target {
             PermissionOverwriteType::Member(user_id) => {
-                (PermissionOverwriteTargetType::Member, user_id.0)
+                (PermissionOverwriteTargetType::Member, user_id.get())
             }
             PermissionOverwriteType::Role(role_id) => {
-                (PermissionOverwriteTargetType::Role, role_id.0)
+                (PermissionOverwriteTargetType::Role, role_id.get())
             }
         };
 
@@ -62,7 +62,7 @@ impl<'a> UpdateChannelPermissionConfigured<'a> {
 
     fn request(&self) -> Result<Request, Error> {
         let mut request = Request::builder(&Route::UpdatePermissionOverwrite {
-            channel_id: self.channel_id.0,
+            channel_id: self.channel_id.get(),
             target_id: self.target_id,
         })
         .json(&self.fields)?;
@@ -108,10 +108,10 @@ mod tests {
         let client = Client::new("foo".to_owned());
         let builder = UpdateChannelPermissionConfigured::new(
             &client,
-            ChannelId(1),
+            ChannelId::new(1).expect("non zero"),
             Permissions::empty(),
             Permissions::SEND_MESSAGES,
-            PermissionOverwriteType::Member(UserId(2)),
+            PermissionOverwriteType::Member(UserId::new(2).expect("non zero")),
         );
         let actual = builder.request().expect("failed to create request");
 
