@@ -21,7 +21,7 @@ impl<'a> GetActiveThreads<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ThreadsListing> {
         let request = Request::from_route(&Route::GetActiveThreads {
-            guild_id: self.guild_id.0,
+            guild_id: self.guild_id.get(),
         });
 
         self.http.request(request)
